/*
This script alters the DOCUMENTPOSITION column of the RQREQUIREMENTS table.  It will change
the column data type to NUMBER(10) instead of NUMBER (without a prescribed length).
This provides a workaround to a problem in the Database type conversion wizard where 0 values can't
be inserted into a NUMBER column of unspecified length.
If errors occur, the user needs to check the DocumentPositionConversion.log file.

Also, if you have a very large number of requirements you may need to set the rollback segment
to prevent the UPDATE statements from running out of rollback space.  The statements to do this
are included below, but commented out.  You will need to specify which rollback segment to use
depending on how your database is set up.
*/

set echo on
whenever sqlerror exit;
spool DocumentPositionConversion.log

CREATE TABLE TEMPREQUIREMENTS (
  ID NUMBER(10),
  DOCUMENTPOSITION NUMBER);
INSERT INTO TEMPREQUIREMENTS SELECT ID, DOCUMENTPOSITION FROM RQREQUIREMENTS;
--SET TRANSACTION USE ROLLBACK SEGMENT <a large rollback segment>;
UPDATE RQREQUIREMENTS SET DOCUMENTPOSITION = NULL;
--COMMIT;
ALTER TABLE RQREQUIREMENTS MODIFY(DOCUMENTPOSITION NUMBER(10));
--SET TRANSACTION USE ROLLBACK SEGMENT <a large rollback segment>;
UPDATE RQREQUIREMENTS R SET DOCUMENTPOSITION = 
  (SELECT DOCUMENTPOSITION FROM TEMPREQUIREMENTS T
   WHERE T.ID = R.ID);
--COMMIT;
DROP TABLE TEMPREQUIREMENTS;

COMMIT;

spool off